==> truffle-runtime-svm-24.2.2.jar: module-info.java <==
module org.graalvm.truffle.runtime.svm {
    requires java.management;
    requires jdk.graal.compiler;
    requires jdk.internal.vm.ci;
    requires jdk.management;
    requires org.graalvm.collections;
    /* static phase */ requires org.graalvm.jniutils;
    /* transitive */ requires org.graalvm.nativeimage;
    /* transitive */ requires org.graalvm.nativeimage.base;
    requires org.graalvm.nativeimage.builder;
    requires org.graalvm.nativeimage.objectfile;
    requires org.graalvm.nativeimage.pointsto;
    requires org.graalvm.polyglot;
    requires org.graalvm.truffle;
    requires org.graalvm.truffle.compiler;
    /* static phase */ requires org.graalvm.truffle.runtime;
    /* transitive */ requires org.graalvm.word;

    exports com.oracle.svm.truffle to com.oracle.truffle.enterprise.svm, org.graalvm.truffle.runtime.svm;
    exports com.oracle.svm.truffle.api to com.oracle.truffle.enterprise.svm, org.graalvm.truffle, org.graalvm.truffle.runtime.svm;
    exports com.oracle.svm.truffle.isolated to com.oracle.truffle.enterprise.svm, org.graalvm.truffle.runtime.svm;
    exports com.oracle.svm.truffle.nfi to com.oracle.truffle.enterprise.svm, org.graalvm.truffle.runtime.svm;
    exports com.oracle.svm.truffle.nfi.libffi to com.oracle.truffle.enterprise.svm, org.graalvm.truffle.runtime.svm;
    exports com.oracle.svm.truffle.nfi.posix to com.oracle.truffle.enterprise.svm, org.graalvm.truffle.runtime.svm;
    exports com.oracle.svm.truffle.nfi.windows to com.oracle.truffle.enterprise.svm, org.graalvm.truffle.runtime.svm;

    opens com.oracle.svm.truffle to org.graalvm.nativeimage.builder, jdk.graal.compiler;
    opens com.oracle.svm.truffle.api to org.graalvm.nativeimage.builder, jdk.graal.compiler;
    opens com.oracle.svm.truffle.isolated to org.graalvm.nativeimage.builder, jdk.graal.compiler;
    opens com.oracle.svm.truffle.nfi to org.graalvm.nativeimage.builder, jdk.graal.compiler;
    opens com.oracle.svm.truffle.nfi.posix to org.graalvm.nativeimage.builder, jdk.graal.compiler;
    opens com.oracle.svm.truffle.nfi.windows to org.graalvm.nativeimage.builder, jdk.graal.compiler;

    provides GeneratedPluginFactory with PluginFactory_SubstrateTruffleOptions, PluginFactory_SubstrateThreadLocalHandshakeSnippets;
    provides OptionDescriptors with SubstrateTruffleOptions_OptionDescriptors, TruffleBaseFeature_OptionDescriptors, TruffleFeature_OptionDescriptors;

}

==> truffle-runtime-svm-25.0.0.jar: module-info.java <==
module org.graalvm.truffle.runtime.svm {
    requires java.management;
    requires jdk.graal.compiler;
    requires jdk.internal.vm.ci;
    requires jdk.management;
    requires org.graalvm.collections;
    /* static phase */ requires org.graalvm.jniutils;
    /* transitive */ requires org.graalvm.nativeimage;
    /* transitive */ requires org.graalvm.nativeimage.base;
    requires org.graalvm.nativeimage.builder;
    requires org.graalvm.nativeimage.objectfile;
    requires org.graalvm.nativeimage.pointsto;
    requires org.graalvm.polyglot;
    requires org.graalvm.truffle;
    requires org.graalvm.truffle.compiler;
    /* static phase */ requires org.graalvm.truffle.runtime;
    /* transitive */ requires org.graalvm.word;

    exports com.oracle.svm.truffle to com.oracle.truffle.enterprise.svm, org.graalvm.truffle.runtime.svm;
    exports com.oracle.svm.truffle.api to com.oracle.truffle.enterprise.svm, org.graalvm.truffle, org.graalvm.truffle.runtime.svm;
    exports com.oracle.svm.truffle.isolated to com.oracle.truffle.enterprise.svm, org.graalvm.truffle.runtime.svm;
    exports com.oracle.svm.truffle.nfi to com.oracle.truffle.enterprise.svm, org.graalvm.truffle.runtime.svm;
    exports com.oracle.svm.truffle.nfi.libffi to com.oracle.truffle.enterprise.svm, org.graalvm.truffle.runtime.svm;
    exports com.oracle.svm.truffle.nfi.posix to com.oracle.truffle.enterprise.svm, org.graalvm.truffle.runtime.svm;
    exports com.oracle.svm.truffle.nfi.windows to com.oracle.truffle.enterprise.svm, org.graalvm.truffle.runtime.svm;

    opens com.oracle.svm.truffle to org.graalvm.nativeimage.builder, jdk.graal.compiler;
    opens com.oracle.svm.truffle.api to org.graalvm.nativeimage.builder, jdk.graal.compiler;
    opens com.oracle.svm.truffle.isolated to org.graalvm.nativeimage.builder, jdk.graal.compiler;
    opens com.oracle.svm.truffle.nfi to org.graalvm.nativeimage.builder, jdk.graal.compiler;
    opens com.oracle.svm.truffle.nfi.posix to org.graalvm.nativeimage.builder, jdk.graal.compiler;
    opens com.oracle.svm.truffle.nfi.windows to org.graalvm.nativeimage.builder, jdk.graal.compiler;

    provides GeneratedPluginFactory with PluginFactory_SubstrateThreadLocalHandshakeSnippets, PluginFactory_SubstrateTruffleOptions;
    provides OptionDescriptors with TruffleBaseFeature_Options_OptionDescriptors, TruffleFeature_Options_OptionDescriptors, SubstrateTruffleOptions_OptionDescriptors;

}
